@@ -34,7 +34,7 @@ the license. There is NO WARRANTY, to the extent permitted by law.`
 const (
 	PLUGIN_VERSION_MAJOR = 7
 	PLUGIN_VERSION_MINOR = 0
-	PLUGIN_VERSION_PATCH = 3
+	PLUGIN_VERSION_PATCH = 4
 	PLUGIN_VERSION_RC    = ""
 )
 
@@ -60,7 +60,8 @@ func main() {
 	if err != nil {
 		panic(fmt.Sprintf("failed to create plugin handler %s", err.Error()))
 	}
-	plugin.Impl.Logger = &h
+
+	plugin.Impl.Logger = h
 
 	err = h.Execute()
 	if err != nil {
